==> 1.0.43+1.tar.gz: lib/StandardPage.dart <==

import 'package:ui_sdk/props/StandardScreenResponse.dart';
import 'package:ui_sdk/props/ApiResponse.dart';
import 'package:ui_sdk/utils/pubsub/localpubsub.dart';
import 'package:flutter/material.dart';
import 'Renderer.dart';

abstract class StandardPage {
  late StatefulWidget page;
  StandardPage() {
    page = FlutterPage(
      getData(),
      getActions(), // set of strings
      getPageCallBackForAction(),
      /*
        ........................Syntax..............................

        getPageCallBackForAction() {
          return callback();
        }

        void callback() {

        }
      */
      getPageContext(),
      /*
        getPageContext() {
          return pageReference;
        }
      */
    );
  }
  Future<ApiResponse> getData();
  Set<String?> getActions();
  dynamic getPageCallBackForAction();
  dynamic getPageContext();
  StatefulWidget getPage() {
    return page;
  }
}

class FlutterPage extends StatefulWidget {
  Future<ApiResponse> apiData;
  Set<String?> actionList;
  dynamic fun;
  dynamic reference;
  Map<String?, Subscription?>? subArray;

  FlutterPage(this.apiData, this.actionList, this.fun, this.reference,
      {Key? key})
      : super(key: key);

  @override
  State<FlutterPage> createState() => FlutterPageState();
}

class FlutterPageState extends State<FlutterPage> {
  Renderer renderer = Renderer();

  @override
  void initState() {
    super.initState();
    registerEvents();
  }

  registerEvents() {
    //we have to unsubscribe the elements here
    //but for now we don't have to do right now
    widget.subArray = Map();
    PubSub pubsub = PubSub();
    // print("janu");
    // print("rashid ${widget.reference}");
    //   print("entering");
    // print(widget.reference);
    //actionlist array

    //set
    widget.actionList.forEach(
          (element) {
        Subscription? sub;
        sub = pubsub.subscribe(element, widget.reference);

        // print(widget.subArray);
        widget.subArray![element] = sub;
        //  print(widget.subArray);

        sub?.stream?.listen(
              (uikAction) {
            // print(uikAction);
            // print(pubsub.stack.top());

            //because the last reference will always be of Prateek
            //   print("sub");
            //   print(" ${widget.reference}  ${pubsub.stack.top()} ");

            if (widget.reference == pubsub.stack.top()) {
              widget.fun(uikAction);
            }
          },
        );
      },
    );
    // print(widget.subArray);
    //   print("widget.reference ${widget.reference}");
    pubsub.stack.push(widget.reference);
    // print(pubsub.stack.length);
    //print(widget.reference);
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async {
        // print("entering");
        // print("Lavesh ${widget.reference}");
        PubSub pubsub = PubSub();
        pubsub.stack.pop();
        // print(pubsub.stack.top());
        pubsub.unsubscribe(widget.subArray);
        return true;
      },
      child: MaterialApp(
        debugShowCheckedModeBanner: false,
        title: 'Fetch Data Example',
        theme: ThemeData(
          primarySwatch: Colors.blue,
        ),
        home: Scaffold(
          body: Center(
            child: FutureBuilder<ApiResponse>(
              future: widget.apiData,
              builder: (context, snapshot) {
                if (snapshot.hasData) {
                  return renderer.getListWidgetUi(StandardScreenResponse.fromJson(snapshot.data?.data!["response"]));
                  // if (snapshot.requireData.statusCode == 200) {
                  //
                  // } else {
                  //   throw Text('${snapshot.error}');;
                  // }
                } else if (snapshot.hasError) {
                  return Text('${snapshot.error}');
                }

                // By default, show a loading spinner.
                return const CircularProgressIndicator();
              },
            ),
          ),
        ),
      ),
    );
  }
}

==> 1.0.53+1.tar.gz: lib/StandardPage.dart <==
import 'package:ui_sdk/props/StandardScreenResponse.dart';
import 'package:ui_sdk/props/ApiResponse.dart';
import 'package:ui_sdk/utils/pubsub/localpubsub.dart';
import 'package:flutter/material.dart';
import 'Renderer.dart';

abstract class StandardPage {
  late StatefulWidget page;

  Future<ApiResponse> getData();
  Set<String?> getActions();
  dynamic getPageCallBackForAction();
  dynamic getPageContext();

  StandardPage() {
    page = FlutterPage(
      getData(),
      getActions(), // set of strings
      getPageCallBackForAction(),
      /*
        ........................Syntax..............................

        getPageCallBackForAction() {
          return callback();
        }

        void callback() {

        }
      */
      getPageContext(),
      /*
        getPageContext() {
          return pageReference;
        }
      */
    );
  }

  StatefulWidget getPage() {
    return page;
  }
}

class FlutterPage extends StatefulWidget {
  Future<ApiResponse> apiData;
  Set<String?> actionList;
  dynamic fun;
  dynamic reference;
  Map<String?, Subscription?>? subArray;

  FlutterPage(this.apiData, this.actionList, this.fun, this.reference,
      {Key? key})
      : super(key: key);

  @override
  State<FlutterPage> createState() => FlutterPageState();
}

class FlutterPageState extends State<FlutterPage> {
  Renderer renderer = Renderer();

  @override
  void initState() {
    super.initState();
    registerEvents();
  }

  registerEvents() {
    //we have to unsubscribe the elements here
    //but for now we don't have to do right now
    widget.subArray = Map();
    PubSub pubsub = PubSub();
    // print("janu");
    // print("rashid ${widget.reference}");
    //   print("entering");
    // print(widget.reference);
    //actionlist array

    //set
    widget.actionList.forEach(
      (element) {
        Subscription? sub;
        sub = pubsub.subscribe(element, widget.reference);

        // print(widget.subArray);
        widget.subArray![element] = sub;
        //  print(widget.subArray);

        sub?.stream?.listen(
          (uikAction) {
            // print(uikAction);
            // print(pubsub.stack.top());

            //because the last reference will always be of Prateek
            //   print("sub");
            //   print(" ${widget.reference}  ${pubsub.stack.top()} ");

            if (widget.reference == pubsub.stack.top()) {
              widget.fun(uikAction);
            }
          },
        );
      },
    );
    // print(widget.subArray);
    //   print("widget.reference ${widget.reference}");
    pubsub.stack.push(widget.reference);
    // print(pubsub.stack.length);
    //print(widget.reference);
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      onWillPop: () async {
        // print("entering");
        // print("Lavesh ${widget.reference}");
        PubSub pubsub = PubSub();
        pubsub.stack.pop();
        // print(pubsub.stack.top());
        pubsub.unsubscribe(widget.subArray);
        return true;
      },
      child: MaterialApp(
        debugShowCheckedModeBanner: false,
        title: 'Fetch Data Example',
        theme: ThemeData(
          primarySwatch: Colors.blue,
        ),
        home: Scaffold(
          body: Center(
            child: FutureBuilder<ApiResponse>(
              future: widget.apiData,
              builder: (context, snapshot) {
                if (snapshot.hasData) {
                  return renderer.getListWidgetUi(
                    StandardScreenResponse.fromJson(
                      snapshot.requireData.data,
                    ),
                  );
                } else if (snapshot.hasError) {
                  return Text('${snapshot.error}');
                }

                // By default, show a loading spinner.
                return const CircularProgressIndicator();
              },
            ),
          ),
        ),
      ),
    );
  }
}
